@@ -1031,7 +1031,9 @@ fs_rawudp_transmitter_udpport_add_dest (UdpPort *udpport,
   g_signal_emit_by_name (udpport->udpsink, "add", ip, port);
   gst_element_send_event (udpport->udpsink,
       gst_event_new_custom (GST_EVENT_CUSTOM_UPSTREAM,
-          gst_structure_new ("GstForceKeyUnit", NULL)));
+          gst_structure_new ("GstForceKeyUnit",
+              "all-headers", G_TYPE_BOOLEAN, TRUE,
+              NULL)));
 }
 
 
